@@ -86,6 +86,18 @@ class AmpliPi:
         response = await self._client.get(f'streams/{stream_id}')
         return Stream.parse_obj(response)
 
+    async def play_stream(self, stream_id: int) -> Stream:
+        response = await self._client.post(f'streams/{stream_id}/play')
+        return Stream.parse_obj(response)
+
+    async def pause_stream(self, stream_id: int) -> Stream:
+        response = await self._client.post(f'streams/{stream_id}/pause')
+        return Stream.parse_obj(response)
+
+    async def next_stream(self, stream_id: int) -> Stream:
+        response = await self._client.post(f'streams/{stream_id}/next')
+        return Stream.parse_obj(response)
+
     async def create_stream(self, new_stream: Stream) -> Stream:
         response = await self._client.post(f'streams', new_stream.json())
         return Stream.parse_obj(response)
